{% extends "base.html" %}

{% block html_title %}Xsan I/O Monitoring{% endblock %}

{% block page_title %}Xsan I/O Monitoring{% endblock %}

{% block meta %} <meta http-equiv="refresh" content="2"> {% endblock %}

{% block content %}
        <p><a href='{% url volume_list_view %}'>Volume list</a></p>
        <p><a href='{% url client_list_view %}'>Client list</a></p>
        <h2>Total Xsan I/O</h2>
            {% if global_stats %}
                <table border="1">
                    <tr>
                        <td>
                            <b>Read/s</b>
                        </td>
                        <td>
                            <b>Write/s</b>
                        </td>
                        <td>
                            <b>Read, IO/s</b>
                        </td>
                        <td>
                            <b>Write, IO/s</b>
                        </td>
                        <td>
                            <b>Total data rate/s</b>
                        </td>
                        <td>
                            <b>Total, IO/s</b>
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <i>{{ global_stats.bytes_read_sec|filesizeformat }}</i>
                        </td>
                        <td>
                            <i>{{ global_stats.bytes_write_sec|filesizeformat }}</i>
                        </td>
                        <td>
                            <i>{{ global_stats.io_read_sec}}</i>
                        </td>
                        <td>
                            <i>{{ global_stats.io_write_sec}}</i>
                        </td>
                        <td>
                            <i>{{ global_stats.bytes_sec|filesizeformat }}</i>
                        </td>
                        <td>
                            <i>{{ global_stats.io_sec}}</i>
                        </td>
                    </tr>
                </table>
        {% else %}
            <p>No data collected yet. Install xsanio_client on all Xsan clients to gather some.</p>
        {% endif %}
{% endblock %}

{% block footer %}
{% endblock %}