{% extends "base.html" %}

{% block html_title %}Volume list{% endblock %}

{% block page_title %}Volume list{% endblock %}

{% block content %}
        {% if object_list %}
            <ul>
                {% for object in object_list %}
                    <li><a href="{% url volume_detail_view object.id %}">{{ object.name }}</a></li>
                {% endfor %}
            </ul>
        {% else %}
            <p>No volumes discovered. Make sure that you run this application on MDC and have xsanio_backend launched in the background.</p>
        {% endif %}
{% endblock %}
